var classIMP_1_1statistics_1_1VectorDEmbedding =
[
    [ "VectorDEmbedding", "classIMP_1_1statistics_1_1VectorDEmbedding.html#adc7396de005b3afac5181cad5807dc15", null ],
    [ "get_number_of_items", "classIMP_1_1statistics_1_1VectorDEmbedding.html#aaeccf62928ac5472c1f55ac36c33be2d", null ],
    [ "get_point", "classIMP_1_1statistics_1_1VectorDEmbedding.html#ab99085602658220b18669293fca21367", null ],
    [ "get_type_name", "classIMP_1_1statistics_1_1VectorDEmbedding.html#a70d1db0ac846bddc0922aa29a18b7770", null ],
    [ "get_version_info", "classIMP_1_1statistics_1_1VectorDEmbedding.html#ac26c8b992e86a4c6c72f81e45c6514c7", null ]
];